@@ -16,11 +16,10 @@ class Item(BaseModel):
 
 @app.post(
     "/items/",
-    response_model=Item,
     summary="Create an item",
     response_description="The created item",
 )
-async def create_item(item: Item):
+async def create_item(item: Item) -> Item:
     """
     Create an item with all the information:
 
