@@ -3,7 +3,7 @@ from typing import Annotated
 import pytest
 from fastapi import FastAPI, Path
 from fastapi.testclient import TestClient
-from inline_snapshot import snapshot
+from inline_snapshot import Is, snapshot
 
 app = FastAPI()
 
@@ -58,8 +58,8 @@ def test_schema(path: str, expected_name: str, expected_title: str):
         [
             {
                 "required": True,
-                "schema": {"title": expected_title, "type": "string"},
-                "name": expected_name,
+                "schema": {"title": Is(expected_title), "type": "string"},
+                "name": Is(expected_name),
                 "in": "path",
             }
         ]
