@@ -4,6 +4,7 @@ import pytest
 from dirty_equals import IsOneOf
 from fastapi import FastAPI, Query
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 from pydantic import BaseModel, Field
 
 app = FastAPI()
@@ -31,14 +32,16 @@ async def read_model_required_str(p: Annotated[QueryModelRequiredStr, Query()]):
     ["/required-str", "/model-required-str"],
 )
 def test_required_str_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": True,
-            "schema": {"title": "P", "type": "string"},
-            "name": "p",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": True,
+                "schema": {"title": "P", "type": "string"},
+                "name": "p",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -95,14 +98,16 @@ async def read_model_required_alias(p: Annotated[QueryModelRequiredAlias, Query(
     ["/required-alias", "/model-required-alias"],
 )
 def test_required_str_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": True,
-            "schema": {"title": "P Alias", "type": "string"},
-            "name": "p_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": True,
+                "schema": {"title": "P Alias", "type": "string"},
+                "name": "p_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -192,14 +197,16 @@ def read_model_required_validation_alias(
     ["/required-validation-alias", "/model-required-validation-alias"],
 )
 def test_required_validation_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": True,
-            "schema": {"title": "P Val Alias", "type": "string"},
-            "name": "p_val_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": True,
+                "schema": {"title": "P Val Alias", "type": "string"},
+                "name": "p_val_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -297,14 +304,16 @@ def read_model_required_alias_and_validation_alias(
     ],
 )
 def test_required_alias_and_validation_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": True,
-            "schema": {"title": "P Val Alias", "type": "string"},
-            "name": "p_val_alias",
-            "in": "query",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": True,
+                "schema": {"title": "P Val Alias", "type": "string"},
+                "name": "p_val_alias",
+                "in": "query",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
