@@ -1,4 +1,5 @@
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 
 from docs_src.metadata.tutorial003_py39 import app
 
@@ -14,27 +15,29 @@ def test_items():
 def test_openapi_schema():
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
-    assert response.json() == {
-        "openapi": "3.1.0",
-        "info": {
-            "title": "FastAPI",
-            "version": "0.1.0",
-        },
-        "paths": {
-            "/items/": {
-                "get": {
-                    "summary": "Read Items",
-                    "operationId": "read_items_items__get",
-                    "responses": {
-                        "200": {
-                            "description": "Successful Response",
-                            "content": {"application/json": {"schema": {}}},
-                        }
-                    },
+    assert response.json() == snapshot(
+        {
+            "openapi": "3.1.0",
+            "info": {
+                "title": "FastAPI",
+                "version": "0.1.0",
+            },
+            "paths": {
+                "/items/": {
+                    "get": {
+                        "summary": "Read Items",
+                        "operationId": "read_items_items__get",
+                        "responses": {
+                            "200": {
+                                "description": "Successful Response",
+                                "content": {"application/json": {"schema": {}}},
+                            }
+                        },
+                    }
                 }
-            }
-        },
-    }
+            },
+        }
+    )
 
 
 def test_swagger_ui_default_url():
