@@ -1,4 +1,5 @@
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 
 from docs_src.path_operation_advanced_configuration.tutorial003_py39 import app
 
@@ -14,8 +15,10 @@ def test_get():
 def test_openapi_schema():
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
-    assert response.json() == {
-        "openapi": "3.1.0",
-        "info": {"title": "FastAPI", "version": "0.1.0"},
-        "paths": {},
-    }
+    assert response.json() == snapshot(
+        {
+            "openapi": "3.1.0",
+            "info": {"title": "FastAPI", "version": "0.1.0"},
+            "paths": {},
+        }
+    )
