@@ -2,6 +2,7 @@ import importlib
 
 import pytest
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 
 
 @pytest.fixture(
@@ -75,41 +76,43 @@ def test_post_invalid(client: TestClient):
 def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
-    assert response.json() == {
-        "openapi": "3.1.0",
-        "info": {"title": "FastAPI", "version": "0.1.0"},
-        "paths": {
-            "/items/": {
-                "post": {
-                    "summary": "Create Item",
-                    "operationId": "create_item_items__post",
-                    "requestBody": {
-                        "content": {
-                            "application/x-yaml": {
-                                "schema": {
-                                    "title": "Item",
-                                    "required": ["name", "tags"],
-                                    "type": "object",
-                                    "properties": {
-                                        "name": {"title": "Name", "type": "string"},
-                                        "tags": {
-                                            "title": "Tags",
-                                            "type": "array",
-                                            "items": {"type": "string"},
+    assert response.json() == snapshot(
+        {
+            "openapi": "3.1.0",
+            "info": {"title": "FastAPI", "version": "0.1.0"},
+            "paths": {
+                "/items/": {
+                    "post": {
+                        "summary": "Create Item",
+                        "operationId": "create_item_items__post",
+                        "requestBody": {
+                            "content": {
+                                "application/x-yaml": {
+                                    "schema": {
+                                        "title": "Item",
+                                        "required": ["name", "tags"],
+                                        "type": "object",
+                                        "properties": {
+                                            "name": {"title": "Name", "type": "string"},
+                                            "tags": {
+                                                "title": "Tags",
+                                                "type": "array",
+                                                "items": {"type": "string"},
+                                            },
                                         },
-                                    },
+                                    }
                                 }
+                            },
+                            "required": True,
+                        },
+                        "responses": {
+                            "200": {
+                                "description": "Successful Response",
+                                "content": {"application/json": {"schema": {}}},
                             }
                         },
-                        "required": True,
-                    },
-                    "responses": {
-                        "200": {
-                            "description": "Successful Response",
-                            "content": {"application/json": {"schema": {}}},
-                        }
-                    },
+                    }
                 }
-            }
-        },
-    }
+            },
+        }
+    )
